<?php

/**
 * AuthRepository.php - Repository file
 *
 * This file is part of the Auth component.
 *-----------------------------------------------------------------------------*/

namespace App\Yantrana\Components\Auth\Repositories;

use App\Yantrana\Base\BaseRepository;
use App\Yantrana\Components\Auth\Interfaces\AuthRepositoryInterface;
use App\Yantrana\Components\Auth\Models\AuthModel;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use YesSecurity;

class AuthRepository extends BaseRepository implements AuthRepositoryInterface
{
        /**
     * primary model instance
     *
     * @var object
     */
    protected $primaryModel = AuthModel::class;

    /**
     * Fetch the record of Auth
     *
     * @param    int || string $idOrUid
     * @return eloquent collection object
     *---------------------------------------------------------------- */
    public function fetch($idOrUid)
    {
        if (is_numeric($idOrUid)) {
            return AuthModel::where('_id', $idOrUid)->first();
        }

        return AuthModel::where('_uid', $idOrUid)->first();
    }

    /**
     * Store User.
     *
     * @param  array  $storeData
     *
     *-----------------------------------------------------------------------*/
    public function storeUser($storeData)
    {
        $keyValues = [
            'email',
            'password' => Hash::make($storeData['password']),
            'status' => $storeData['status'],
            'first_name',
            'last_name',
            'username' => Str::lower(Str::slug($storeData['username'])),
            'mobile_number' => array_get($storeData, 'mobile_number'),
            'user_roles__id' => $storeData['user_roles__id'],
            'vendors__id',
        ];

        $keyValues['remember_token'] = YesSecurity::generateUid();

        // Get Instance of user model
        $userModel = new AuthModel;
        // Store New User
        if ($userModel->assignInputsAndSave($storeData, $keyValues)) {
            return $userModel;
        }

        return false;
    }

    public function fetchNeverActivatedUser($userUid)
    {
        return AuthModel::where([
            '_uid' => $userUid,
            'status' => 4,  // never activated
        ])
            ->first();
    }

    public function updateUser($user, $updateData)
    {
        // Check if information updated
        if ($user->modelUpdate($updateData)) {
            return $user;
        }

        return false;
    }
}
