<?php

/**
 * HomeController.php - Controller file
 *
 * This file is part of the Home component.
 *-----------------------------------------------------------------------------*/

namespace App\Yantrana\Components\Home\Controllers;

use App\Yantrana\Base\BaseController;
use App\Yantrana\Components\Home\HomeEngine;
use App\Yantrana\Support\CommonRequest;

class HomeController extends BaseController
{
    /**
     * @var HomeEngine - Home Engine
     */
    protected $homeEngine;

    /**
     * Constructor
     *
     * @param  HomeEngine  $homeEngine  - Home Engine
     * @return void
     *-----------------------------------------------------------------------*/
    public function __construct(HomeEngine $homeEngine)
    {
        $this->homeEngine = $homeEngine;
    }

    public function homePageView()
    {
        return $this->loadView('outer-home');
    }

    //Contact for view load
    public function contactForm()
    {
        return $this->loadView('contact.contact');
    }

    public function contactProcess(CommonRequest $request)
    {
        $request->validate([
            'email' => 'required|email',
            'full_name' => 'required',
            'subject' => 'required',
            'message' => 'required|min:5',
        ]);
        $processReaction = $this->homeEngine->processContactEmail($request->all());

        if ($processReaction['reaction_code'] === 1) {
            return $this->responseAction(
                $this->processResponse($processReaction, [], [], true),
                $this->redirectTo('user.contact.form', [], [
                    __tr('Thank you for contacting us, your request has been submitted successfully, we will get back to you soon.'),
                    'success',
                ])
            );
        }

        return $this->responseAction(
            $this->processResponse($processReaction, [], [], true)
        );
    }

    /**
     * Compiled JS file from server mostly contains the translated words/sentences for the javascript
     *
     * @return view
     */
    public function serverCompiledJs()
    {
        return response()->view('server-compiled-js')->header('Content-Type', 'text/javascript');
    }

    public function noActivePlan()
    {
        return response()->view('errors.no-active-plan');
    }
    public function viewTermsAndPolicies($contentName)
    {
        $validItems = [
            'user_terms' => __tr('User terms'),
            'vendor_terms' => __tr('Vendor terms'),
            'privacy_policy' => __tr('Privacy Policy'),
        ];
        abortIf(!array_key_exists($contentName, $validItems));
        return response()->view('terms-policies', [
            'contentName' => $contentName,
            'validItems' => $validItems,
        ]);
    }
}
