<?php

/**
 * UserController.php - Controller file
 *
 * This file is part of the User component.
 *-----------------------------------------------------------------------------*/

namespace App\Yantrana\Components\User\Controllers;

use App\Yantrana\Base\BaseController;
use App\Yantrana\Base\BaseRequest;
use App\Yantrana\Components\Auth\Models\AuthModel;
use App\Yantrana\Components\User\UserEngine;
use App\Yantrana\Support\CommonClearPostRequest;
use Illuminate\Validation\Rule;

class UserController extends BaseController
{
    /**
     * @var UserEngine - User Engine
     */
    protected $userEngine;

    /**
     * Constructor
     *
     * @param  UserEngine  $userEngine  - User Engine
     * @return void
     *-----------------------------------------------------------------------*/
    public function __construct(UserEngine $userEngine)
    {
        $this->userEngine = $userEngine;
    }

    /**
     * Show the form for editing the profile.
     */
    public function profileEditForm()
    {
        return $this->loadView('user.profile-edit');
    }

    /**
     * Update Profile
     */
    public function updateProfile(CommonClearPostRequest $request)
    {
        // validate information
        $request->validate([
            'first_name' => ['required', 'min:3'],
            'last_name' => ['required', 'min:3'],
            'email' => ['required', 'email',  Rule::unique((new AuthModel)->getTable())->ignore(auth()->id(), '_id')],
        ]);
        // process the request
        $processReaction = $this->userEngine->processUpdateProfile($request->all());

        // response
        return $this->processResponse($processReaction, [], [
            'show_message' => true,
        ], true);
    }

    /**
     * ChangeLocale - It also managed from index.php.
     *---------------------------------------------------------------- */
    protected function changeLocale(BaseRequest $request, $localeId = null)
    {
        if (is_string($localeId)) {
            changeAppLocale($localeId);
            
            if(!$request->ajax()) {
                return redirect('/');
            }

            return $this->processResponse(21, [], [
                'show_message' => true,
                'reloadPage' => true,
            ], true);
        }
        return abort(404);
    }
}
