<?php

/**
 * VendorTransactionRepository.php - Repository file
 *
 * This file is part of the Vendor component.
 *-----------------------------------------------------------------------------*/

namespace App\Yantrana\Components\Vendor\Repositories;

use App\Yantrana\Base\BaseRepository;
use App\Yantrana\Components\Vendor\Interfaces\VendorTransactionRepositoryInterface;
use App\Yantrana\Components\Vendor\Models\VendorTransactionModel;

class VendorTransactionRepository extends BaseRepository implements VendorTransactionRepositoryInterface
{
    /**
     * primary model instance
     *
     * @var object
     */
    protected $primaryModel = VendorTransactionModel::class;

    public function getOrderAmountSum($orderId)
    {
        return $this->primaryModel::where('orders__id', $orderId)->sum('amount');
    }

    public function orderPaymentTransaction($order, $options = [])
    {
        $options = array_merge([
            'txnId' => uniqid('AUTO'),
            'paymentMethod' => null,
            'testMode' => null,
            'paymentStatus' => null,
            // __data
            'paymentDataBy' => null,
            'paymentRawData' => null,
        ], $options);

        $sumOfAmountInSystem = $this->getOrderAmountSum($order->_id);
        $orderAmount = $order->total_amount;
        if ($options['paymentStatus'] and ($sumOfAmountInSystem > 0) and in_array($options['paymentStatus'], configItem('payments.debit_status_codes'))) {
            $orderAmount = '-'.$orderAmount;
        } elseif ($options['paymentStatus'] and ($sumOfAmountInSystem == 0) and in_array($options['paymentStatus'], configItem('payments.debit_status_codes'))) {
            return true;
        }

        return $this->storeIt([
            'txn_id' => $options['txnId'],
            'amount' => $orderAmount,
            'payment_method' => $options['paymentMethod'],
            'currency_code' => $order->currency_code,
            'is_test_mode' => $options['testMode'],
            'orders__id' => $order->_id,
            'vendors__id' => $order->vendors__id,
            '__data' => [
                'payment_data_by' => $options['paymentDataBy'],
                'payment_raw_data' => $options['paymentRawData'],
            ],
        ]);
    }
}
