@php
/**
* Component : BotReply
* Controller : BotReplyController
* File : BotReply.list.blade.php
* ----------------------------------------------------------------------------- */
@endphp
@extends('layouts.app', ['title' => __tr('Bot Replies')])
@section('content')
@include('users.partials.header', [
'title' => __tr('Bot Replies'),
'description' => '',
'class' => 'col-lg-7'
])
<div class="container-fluid mt-lg--6">
    <div class="row">
        <!-- button -->
        <div class="col-xl-12 mb-3">
            <div class="float-right">
                <button type="button" class="lw-btn btn btn-primary " data-toggle="modal"
                data-target="#lwAddNewBotReply"> {{ __tr('Add New Bot Reply') }}</button>
                <x-lw.help-modal :subject="__tr('What are the Bots Replies and How to use it?')">
                    <h3>{{  __tr('Whats are Bots') }}</h3>
                    <p>{{  __tr('Bots are instructions given to the system so when you get message you can set reply message so it will get triggered automatically.') }}</p>
                    </x-lw.help-modal>
            </div>
        </div>
        <!--/ button -->
        <!-- Add New Bot Reply Modal -->
        <x-lw.modal id="lwAddNewBotReply" :header="__tr('Add New Bot Reply')" :hasForm="true">
            <!--  Add New Bot Reply Form -->
            <x-lw.form x-data="{triggerType:''}" id="lwAddNewBotReplyForm"
                :action="route('vendor.bot_reply.write.create')"
                :data-callback-params="['modalId' => '#lwAddNewBotReply', 'datatableId' => '#lwBotReplyList']"
                data-callback="appFuncs.modelSuccessCallback">
                <!-- form body -->
                <div class="lw-form-modal-body">
                    <!-- form fields form fields -->
                    <!-- Name -->
                    <x-lw.input-field type="text" id="lwNameField" data-form-group-class="" :label="__tr('Name')"
                        name="name" required="true" />
                    <!-- /Name -->
                    <!-- Reply_Text -->
                    <div class="form-group">
                        <label for="lwReplyTextField">{{ __tr('Reply Text') }}</label>
                        <textarea cols="10" rows="3" id="lwReplyTextField" class="lw-form-field form-control"
                            placeholder="{{ __tr('Reply Text') }}" name="reply_text" required="true"></textarea>
                            <div class="help-text my-3 border p-3">{{  __tr('You are free to use following dynamic variables for reply text, which will get replaced with contact\'s concerned field value.') }} <div><code>{{ implode(' ', $dynamicFields) }}</code></div></div>
                    </div>
                    <!-- /Reply_Text -->
                    <!-- Trigger_Type -->
                    <x-lw.input-field x-model="triggerType" type="selectize" id="lwTriggerTypeField"
                        data-form-group-class="" data-selected=" " :label="__tr('Trigger Type')" name="trigger_type"
                        required="true">
                        <x-slot name="selectOptions">
                            <option value="">{{ __tr('Trigger Type') }}</option>
                            @foreach (configItem('bot_reply_trigger_types') as $replyBotTypeKey => $replyBotType)
                            <option value="{{ $replyBotTypeKey }}">{{ $replyBotType['title'] }} </option>
                            @endforeach
                        </x-slot>
                    </x-lw.input-field>
                    <!-- /Trigger_Type -->
                    @foreach (configItem('bot_reply_trigger_types') as $replyBotTypeKey => $replyBotType)
                    <div x-show="triggerType == '{{ $replyBotTypeKey }}'" class="alert alert-dark">{{
                        $replyBotType['description'] }}</div>
                    @endforeach
                    <!-- Reply_Trigger -->
                    <div x-show="triggerType != 'welcome'">
                        <x-lw.input-field type="text" id="lwReplyTriggerField" data-form-group-class=""
                            :label="__tr('Reply Trigger')" name="reply_trigger" required="true" />
                    </div>
                    <!-- /Reply_Trigger -->
                </div>
                <!-- form footer -->
                <div class="modal-footer">
                    <!-- Submit Button -->
                    <button type="submit" class="btn btn-primary">{{ __('Submit') }}</button>
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">{{ __tr('Close') }}</button>
                </div>
            </x-lw.form>
            <!--/  Add New Bot Reply Form -->
        </x-lw.modal>
        <!--/ Add New Bot Reply Modal -->

        <!-- Details Bot Reply Modal -->
        <x-lw.modal id="lwDetailsBotReply" :header="__tr('Bot Reply Details')">
            <!--  Details Bot Reply Form -->
            <!-- Details body -->
            <div id="lwDetailsBotReplyBody" class="lw-form-modal-body"></div>
            <script type="text/template" id="lwDetailsBotReplyBody-template">
                <!-- form fields -->
                <div class="mb-3">
                    <label class="small">{{ __tr('Name') }}:</label>
                    <div class="lw-details-item">
                        <%- __tData.name %>
                    </div>
                </div>

                <div class="mb-3">
                    <label class="small">{{ __tr('Reply Text') }}:</label>
                    <div class="lw-details-item">
                        <%- __tData.reply_text %>
                    </div>
                </div>

                <div class="mb-3">
                    <label class="small">{{ __tr('Trigger Type') }}:</label>
                    <div class="lw-details-item">
                        <%- __tData.trigger_type %>
                    </div>
                </div>

                <div class="mb-3">
                    <label class="small">{{ __tr('Reply Trigger') }}:</label>
                    <div class="lw-details-item">
                        <%- __tData.reply_trigger %>
                    </div>
                </div>
            </script>
            <!--/  Details Bot Reply Form -->
        </x-lw.modal>
        <!--/ Edit Bot Reply Modal -->

        <!-- Edit Bot Reply Modal -->
        <x-lw.modal id="lwEditBotReply" :header="__tr('Edit Bot Reply')" :hasForm="true">
            <!--  Edit Bot Reply Form -->
            <x-lw.form id="lwEditBotReplyForm" :action="route('vendor.bot_reply.write.update')"
                :data-callback-params="['modalId' => '#lwEditBotReply', 'datatableId' => '#lwBotReplyList']"
                data-callback="appFuncs.modelSuccessCallback">
                <!-- form body -->
                <div id="lwEditBotReplyBody" class="lw-form-modal-body"></div>
                <script type="text/template" id="lwEditBotReplyBody-template">
                    <div>
                    <input type="hidden" name="botReplyIdOrUid" value="<%- __tData._uid %>" />
                        <!-- form fields -->
                        <!-- Name -->
           <x-lw.input-field type="text" id="lwNameEditField" data-form-group-class="" :label="__tr('Name')" value="<%- __tData.name %>" name="name"  required="true"                 />
                <!-- /Name -->
                <!-- Reply_Text -->
                <div class="form-group">
                <label for="lwReplyTextEditField">{{ __tr('Reply Text') }}</label>
                <textarea cols="10" rows="3" id="lwReplyTextEditField" value="<%- __tData.reply_text %>" class="lw-form-field form-control" placeholder="{{ __tr('Reply Text') }}" name="reply_text"  required="true"><%- __tData.reply_text %></textarea>
                <div class="help-text my-3 border p-3">{{  __tr('You are free to use following dynamic variables for reply text, which will get replaced with contact\'s concerned field value.') }} <div><code>{{ implode(' ', $dynamicFields) }}</code></div></div>
            </div>
                <!-- /Reply_Text -->
                <!-- Trigger_Type -->
                 <x-lw.input-field class="disabled" disabled type="selectize" id="lwTriggerTypeEditField" data-form-group-class="" data-selected="<%- __tData.trigger_type %>" :label="__tr('Trigger Type')" name="trigger_type"  required="true">
                    <x-slot name="selectOptions">
                        <option value="">{{ __tr('Trigger Type') }}</option>
                        @foreach (configItem('bot_reply_trigger_types') as $replyBotTypeKey => $replyBotType)
                            <option value="{{ $replyBotTypeKey }}">{{ $replyBotType['title'] }} </option>
                            @endforeach
                        </x-slot>
                    </x-lw.input-field>
                    <!-- /Trigger_Type -->
                    @foreach (configItem('bot_reply_trigger_types') as $replyBotTypeKey => $replyBotType)
                    <% if(__tData.trigger_type == '{{ $replyBotTypeKey }}') { %>
                    <div class="alert alert-dark">{{ $replyBotType['description'] }}</div>
                    <% } %>
                    @endforeach
                    <!-- Reply_Trigger -->
                    <% if(__tData.trigger_type != 'welcome') { %>
                        <x-lw.input-field type="text" id="lwReplyTriggerEditField" data-form-group-class="" :label="__tr('Reply Trigger')" value="<%- __tData.reply_trigger %>" name="reply_trigger"  required="true"/>
           <% } %>
        </div>
                <!-- /Reply_Trigger -->
                     </script>
                <!-- form footer -->
                <div class="modal-footer">
                    <!-- Submit Button -->
                    <button type="submit" class="btn btn-primary">{{ __('Submit') }}</button>
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">{{ __tr('Close') }}</button>
                </div>
            </x-lw.form>
            <!--/  Edit Bot Reply Form -->
        </x-lw.modal>
        <!--/ Edit Bot Reply Modal -->
        <div class="col-xl-12">
            <x-lw.datatable id="lwBotReplyList" :url="route('vendor.bot_reply.read.list')">
                <th data-orderable="true" data-name="name">{{ __tr('Name') }}</th>
                <th data-name="reply_text">{{ __tr('Reply') }}</th>
                <th data-orderable="true" data-name="trigger_type">{{ __tr('Trigger Type') }}</th>
                <th data-orderable="true" data-name="reply_trigger">{{ __tr('Trigger Subject') }}</th>
                <th data-template="#botReplyActionColumnTemplate" name="null">{{ __tr('Action') }}</th>
            </x-lw.datatable>
        </div>
        <!-- action template -->
        <script type="text/template" id="botReplyActionColumnTemplate">
            <a data-pre-callback="appFuncs.clearContainer" title="{{  __tr('Details') }}" class="lw-btn btn btn-sm btn-default lw-ajax-link-action" data-response-template="#lwDetailsBotReplyBody" href="<%= __Utils.apiURL("{{ route('vendor.bot_reply.read.update.data', [ 'botReplyIdOrUid']) }}", {'botReplyIdOrUid': __tData._uid}) %>"  data-toggle="modal" data-target="#lwDetailsBotReply"><i class="fa fa-info-circle"></i> {{  __tr('Details') }}</a>
            <a data-pre-callback="appFuncs.clearContainer" title="{{  __tr('Edit') }}" class="lw-btn btn btn-sm btn-default lw-ajax-link-action" data-response-template="#lwEditBotReplyBody" href="<%= __Utils.apiURL("{{ route('vendor.bot_reply.read.update.data', [ 'botReplyIdOrUid']) }}", {'botReplyIdOrUid': __tData._uid}) %>"  data-toggle="modal" data-target="#lwEditBotReply"><i class="fa fa-edit"></i> {{  __tr('Edit') }}</a>
<!--  Delete Action -->
<a data-method="post" href="<%= __Utils.apiURL("{{ route('vendor.bot_reply.write.delete', [ 'botReplyIdOrUid']) }}", {'botReplyIdOrUid': __tData._uid}) %>" class="btn btn-danger btn-sm lw-ajax-link-action-via-confirm" data-confirm="#lwDeleteBotReply-template" title="{{ __tr('Delete') }}" data-callback-params="{{ json_encode(['datatableId' => '#lwBotReplyList']) }}" data-callback="appFuncs.modelSuccessCallback"><i class="fa fa-trash"></i> {{  __tr('Delete') }}</a>
    </script>
        <!-- /action template -->

        <!-- Bot Reply delete template -->
        <script type="text/template" id="lwDeleteBotReply-template">
            <h2>{{ __tr('Are You Sure!') }}</h2>
            <p>{{ __tr('Are you sure you want to delete this Bot Reply?') }}</p>
    </script>
        <!-- /Bot Reply delete template -->
    </div>
</div>
@endsection()